@@ -14,15 +14,18 @@ public:
     ObjectBar(YWindow *parent);
     virtual ~ObjectBar();
 
+    void configure(const YRect &r, const bool resized);
+
     virtual void addObject(DObject *object);
     virtual void addSeparator();
     virtual void addContainer(char *name, YIcon *icon, ObjectContainer *container);
 
-    virtual void paint(Graphics &g, int x, int y, unsigned int width, unsigned int height);
+    virtual void paint(Graphics &g, const YRect &r);
 
     void addButton(const char *name, YIcon *icon, YButton *button);
     
 private:
+    YArray<YButton *> objects;
     static YColor *bgColor;
 };
 
