@@ -751,21 +751,27 @@ Window YWindowManager::findWindow(Window root, char const * wmInstance,
 }
 
 YFrameWindow *YWindowManager::findFrame(Window win) {
-    YFrameWindow *frame;
+    union {
+        YFrameWindow *ptr;
+        XPointer xptr;
+    } frame;
 
     if (XFindContext(xapp->display(), win,
-                     frameContext, (XPointer *)&frame) == 0)
-        return frame;
+                     frameContext, &(frame.xptr)) == 0)
+        return frame.ptr;
     else
         return 0;
 }
 
 YFrameClient *YWindowManager::findClient(Window win) {
-    YFrameClient *client;
+    union {
+        YFrameClient *ptr;
+        XPointer xptr;
+    } client;
 
     if (XFindContext(xapp->display(), win,
-                     clientContext, (XPointer *)&client) == 0)
-        return client;
+                     clientContext, &(client.xptr)) == 0)
+        return client.ptr;
     else
         return 0;
 }
@@ -977,15 +983,22 @@ int addco(int *v, int &n, int c) {
     return 1;
 }
 
-int YWindowManager::calcCoverage(bool down, YFrameWindow *frame, int x, int y, int w, int h) {
+int YWindowManager::calcCoverage(bool down, YFrameWindow *frame1, int x, int y, int w, int h) {
     int cover = 0;
     int factor = down ? 2 : 1; // try harder not to cover top windows
 
+    YFrameWindow *frame = 0;
+
+    if (down) {
+        frame = top(frame1->getActiveLayer());
+    } else {
+        frame = frame1;
+    }
     for (YFrameWindow * f = frame; f ; f = (down ? f->next() : f->prev())) {
-        if (f == frame || f->isMinimized() || f->isHidden() || !f->isManaged())
+        if (f == frame1 || f->isMinimized() || f->isHidden() || !f->isManaged())
             continue;
 
-        if (!f->isSticky() && f->getWorkspace() != frame->getWorkspace())
+        if (!f->isSticky() && f->getWorkspace() != frame1->getWorkspace())
             continue;
 
         cover +=
@@ -1025,9 +1038,9 @@ void YWindowManager::tryCover(bool down, YFrameWindow *frame, int x, int y, int
     }
 }
 
-bool YWindowManager::getSmartPlace(bool down, YFrameWindow *frame, int &x, int &y, int w, int h, int xiscreen) {
+bool YWindowManager::getSmartPlace(bool down, YFrameWindow *frame1, int &x, int &y, int w, int h, int xiscreen) {
     int mx, my, Mx, My;
-    manager->getWorkArea(frame, &mx, &my, &Mx, &My, xiscreen);
+    manager->getWorkArea(frame1, &mx, &my, &Mx, &My, xiscreen);
 
     x = mx;
     y = my;
@@ -1035,6 +1048,13 @@ bool YWindowManager::getSmartPlace(bool down, YFrameWindow *frame, int &x, int &
     int *xcoord, *ycoord;
     int xcount, ycount;
     int n = 0;
+    YFrameWindow *frame = 0;
+
+    if (down) {
+        frame = top(frame1->getActiveLayer());
+    } else {
+        frame = frame1;
+    }
     YFrameWindow *f = 0;
 
     for (f = frame; f; f = (down ? f->next() : f->prev()))
@@ -1051,10 +1071,10 @@ bool YWindowManager::getSmartPlace(bool down, YFrameWindow *frame, int &x, int &
     addco(xcoord, xcount, mx);
     addco(ycoord, ycount, my);
     for (f = frame; f; f = (down ? f->next() : f->prev())) {
-        if (f == frame || f->isMinimized() || f->isHidden() || !f->isManaged() || f->isMaximized())
+        if (f == frame1 || f->isMinimized() || f->isHidden() || !f->isManaged() || f->isMaximized())
             continue;
 
-        if (!f->isSticky() && f->getWorkspace() != frame->getWorkspace())
+        if (!f->isSticky() && f->getWorkspace() != frame1->getWorkspace())
             continue;
 
         addco(xcoord, xcount, f->x());
@@ -1069,15 +1089,15 @@ bool YWindowManager::getSmartPlace(bool down, YFrameWindow *frame, int &x, int &
 
     int xn = 0, yn = 0;
     px = x; py = y;
-    cover = calcCoverage(down, frame, x, y, w, h);
+    cover = calcCoverage(down, frame1, x, y, w, h);
     while (1) {
         x = xcoord[xn];
         y = ycoord[yn];
 
-        tryCover(down, frame, x - w, y - h, w, h, px, py, cover, xiscreen);
-        tryCover(down, frame, x - w, y    , w, h, px, py, cover, xiscreen);
-        tryCover(down, frame, x    , y - h, w, h, px, py, cover, xiscreen);
-        tryCover(down, frame, x    , y    , w, h, px, py, cover, xiscreen);
+        tryCover(down, frame1, x - w, y - h, w, h, px, py, cover, xiscreen);
+        tryCover(down, frame1, x - w, y    , w, h, px, py, cover, xiscreen);
+        tryCover(down, frame1, x    , y - h, w, h, px, py, cover, xiscreen);
+        tryCover(down, frame1, x    , y    , w, h, px, py, cover, xiscreen);
 
         if (cover == 0)
             break;
@@ -1173,16 +1193,18 @@ void YWindowManager::setWindows(YFrameWindow **w, int count, YAction *action) {
     if (count == 0)
         return;
 
+    lockFocus();
     for (int i = 0; i < count; ++i) {
         YFrameWindow *f = w[i];
         if (action == actionHideAll) {
             if (!f->isHidden())
-                f->wmHide();
+                f->setState(WinStateHidden, WinStateHidden);
         } else if (action == actionMinimizeAll) {
             if (!f->isMinimized())
-                f->wmMinimize();
+                f->setState(WinStateMinimized, WinStateMinimized);
         }
     }
+    unlockFocus();
 }
 
 void YWindowManager::getNewPosition(YFrameWindow *frame, int &x, int &y, int w, int h, int xiscreen) {
@@ -1205,7 +1227,7 @@ void YWindowManager::placeWindow(YFrameWindow *frame,
                                  int cw, int ch,
                                  bool newClient, bool &
 #ifdef CONFIG_SESSION
-                                 canActivate
+                                 doActivate
 #endif
                                 )
 {
@@ -1221,8 +1243,7 @@ void YWindowManager::placeWindow(YFrameWindow *frame,
 #ifdef CONFIG_SESSION
     if (smapp->haveSessionManager() && findWindowInfo(frame)) {
         if (frame->getWorkspace() != manager->activeWorkspace())
-            canActivate = false;
-        return ;
+            doActivate = false;
     }
 #ifndef NO_WINDOW_OPTIONS
     else
@@ -1309,8 +1330,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     int cw = 1;
     int ch = 1;
     bool canManualPlace = false;
-    bool canActivate = true;
-
+    bool doActivate = (wmState() == YWindowManager::wmRUNNING);
+    bool requestFocus = true;
 
     MSG(("managing window 0x%lX", win));
     frame = findFrame(win);
@@ -1382,11 +1403,17 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     MSG(("initial geometry 2 (%d:%d %dx%d)",
          client->x(), client->y(), client->width(), client->height()));
 
-    frame->doManage(client);
+    if (!mapClient) {
+        /// !!! fix (new internal state)
+        //frame->setState(WinStateHidden, WinStateHidden);
+        doActivate = false;
+    }
+
+    frame->doManage(client, doActivate, requestFocus);
     MSG(("initial geometry 3 (%d:%d %dx%d)",
          client->x(), client->y(), client->width(), client->height()));
 
-    placeWindow(frame, cx, cy, cw, ch, (wmState() != wmSTARTUP), canActivate);
+    placeWindow(frame, cx, cy, cw, ch, (wmState() != wmSTARTUP), doActivate);
 
     if ((limitSize || limitPosition) &&
         (wmState() != wmSTARTUP) &&
@@ -1428,16 +1455,29 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
         frame->setNormalGeometryInner(posX, posY, posWidth, posHeight);
     }
 
-    if (!mapClient) {
-        /// !!! fix (new internal state)
-        frame->setState(WinStateHidden, WinStateHidden);
-    }
-    if (frame->frameOptions() & YFrameWindow::foMinimized) {
-        frame->setState(WinStateMinimized, WinStateMinimized);
+    if (wmState() == YWindowManager::wmRUNNING) {
+#ifndef NO_WINDOW_OPTIONS
+        if (frame->frameOptions() & YFrameWindow::foAllWorkspaces)
+            frame->setSticky(true);
+#endif
+#ifndef NO_WINDOW_OPTIONS
+        if (frame->frameOptions() & YFrameWindow::foFullscreen)
+            frame->setState(WinStateFullscreen, WinStateFullscreen);
+#endif
+#ifndef NO_WINDOW_OPTIONS
+        if (frame->frameOptions() & (YFrameWindow::foMaximizedVert | YFrameWindow::foMaximizedHorz))
+            frame->setState(WinStateMaximizedVert | WinStateMaximizedHoriz,
+                            ((frame->frameOptions() & YFrameWindow::foMaximizedVert) ? WinStateMaximizedVert : 0) |
+                            ((frame->frameOptions() & YFrameWindow::foMaximizedHorz) ? WinStateMaximizedHoriz : 0));
+#endif
+        if (frame->frameOptions() & YFrameWindow::foMinimized) {
+            frame->setState(WinStateMinimized, WinStateMinimized);
+        }
     }
+
     frame->setManaged(true);
 
-    if (canActivate && manualPlacement && wmState() == wmRUNNING &&
+    if (doActivate && manualPlacement && wmState() == wmRUNNING &&
 #ifdef CONFIG_WINLIST
         client != windowList &&
 #endif
@@ -1446,7 +1486,7 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
          !(client->sizeHints()->flags & (USPosition | PPosition))))
         canManualPlace = true;
 
-    if (mapClient) {
+    if (doActivate) {
         if (!(frame->getState() & (WinStateHidden | WinStateMinimized | WinStateFullscreen)))
         {
             if (canManualPlace && !opaqueMove)
@@ -1460,26 +1500,15 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
 #endif
     if (frame->affectsWorkArea())
         updateWorkArea();
-    if (mapClient) {
-        if (!(frame->getState() & (WinStateHidden | WinStateMinimized)))
-        {
-            if (wmState() == wmRUNNING && canActivate)
-                frame->focusOnMap();
+    if (wmState() == wmRUNNING) {
+        if (doActivate == 1) {
+            frame->activateWindow(true);
             if (canManualPlace && opaqueMove)
                 frame->wmMove();
+        } else if (requestFocus) {
+            frame->setWmUrgency(true);
         }
     }
-#if 1
-    if (wmState() == wmRUNNING) {
-#ifndef NO_WINDOW_OPTIONS
-        if (frame->frameOptions() & (YFrameWindow::foMaximizedVert | YFrameWindow::foMaximizedHorz))
-            frame->setState(
-                WinStateMaximizedVert | WinStateMaximizedHoriz,
-                ((frame->frameOptions() & YFrameWindow::foMaximizedVert) ? WinStateMaximizedVert : 0) |
-                ((frame->frameOptions() & YFrameWindow::foMaximizedHorz) ? WinStateMaximizedHoriz : 0));
-#endif
-    }
-#endif
     manager->updateFullscreenLayerEnable(true);
 end:
     XUngrabServer(xapp->display());
@@ -1574,8 +1603,8 @@ YFrameWindow *YWindowManager::getLastFocus(long workspace) {
     if (toFocus != 0) {
         if (toFocus->isMinimized() ||
             toFocus->isHidden() ||
-            !toFocus->isFocusable(true) ||
-            !toFocus->visibleOn(workspace))
+            !toFocus->visibleOn(workspace) ||
+            toFocus->avoidFocus())
             toFocus = 0;
     }
 
@@ -1593,14 +1622,14 @@ YFrameWindow *YWindowManager::getLastFocus(long workspace) {
                     continue;
                 if (w->isHidden())
                     continue;
-                if (!w->isFocusable(true))
-                    continue;
                 if (!w->visibleOn(workspace))
                     continue;
-                if (!w->isSticky() || pass == 1) {
-                    toFocus = w;
-                    goto gotit;
-                }
+                if (w->avoidFocus() || pass == 1)
+                    continue;
+                if (w->isSticky() || pass == 1)
+                    continue;
+                toFocus = w;
+                goto gotit;
             }
         }
     }
@@ -1629,6 +1658,8 @@ gotit:
 void YWindowManager::focusLastWindow() {
     if (wmState() != wmRUNNING)
         return ;
+    if (focusLocked())
+        return;
     if (!clickFocus && strongPointerFocus) {
         XSetInputFocus(xapp->display(), PointerRoot, RevertToNone, CurrentTime);
         return ;
@@ -1676,21 +1707,14 @@ void YWindowManager::updateFullscreenLayer() { /// HACK !!!
     }
 }
 
-void YWindowManager::restackWindows(YFrameWindow *win) {
+void YWindowManager::restackWindows(YFrameWindow *) {
     int count = 0;
     YFrameWindow *f;
     YPopupWindow *p;
-    long ll;
 
-    for (f = win; f; f = f->prev())
+    for (f = topLayer(); f; f = f->nextLayer())
         count++;
 
-    for (ll = win->getActiveLayer() + 1; ll < WinLayerCount; ll++) {
-        f = bottom(ll);
-        for (; f; f = f->prev())
-            count++;
-    }
-
 #ifndef LITE
     if (statusMoveSize && statusMoveSize->visible())
         count++;
@@ -1721,7 +1745,7 @@ void YWindowManager::restackWindows(YFrameWindow *win) {
     if (count == 0)
         return ;
 
-    count++;
+    count++; // permanent top window
 
     Window *w = new Window[count];
     if (w == 0)
@@ -1759,36 +1783,15 @@ void YWindowManager::restackWindows(YFrameWindow *win) {
         w[i++] = statusMoveSize->handle();
 #endif
 
-    for (ll = WinLayerCount - 1; ll > win->getActiveLayer(); ll--) {
-        for (f = top(ll); f; f = f->next())
-            w[i++] = f->handle();
-    }
-    for (f = top(win->getActiveLayer()); f; f = f->next()) {
+    for (f = topLayer(); f; f = f->nextLayer()) {
         w[i++] = f->handle();
-        if (f == win)
-            break;
     }
 
-    if (count > 0) {
-#if 0
-        /* remove this code if ok !!! must determine correct top window */
-#if 1
-        XRaiseWindow(xapp->display(), w[0]);
-#else
-        if (win->next()) {
-            XWindowChanges xwc;
-
-            xwc.sibling = win->next()->handle();
-            xwc.stack_mode = Above;
-            XConfigureWindow(xapp->display(), w[0], CWSibling | CWStackMode, &xwc);
-        }
-#endif
-        if (count > 1)
-#endif
+    if (count > 1) {
         XRestackWindows(xapp->display(), w, count);
     }
     if (i != count) {
-        MSG(("i=%d, count=%d", i, count));
+        warn("i=%d, count=%d", i, count);
     }
     PRECONDITION(i == count);
     delete[] w;
@@ -2076,16 +2079,16 @@ void YWindowManager::activateWorkspace(long workspace) {
 
         YFrameWindow *w;
 
-        for (w = bottomLayer(); w; w = w->prevLayer())
-            if (!w->visibleNow()) {
+        for (w = topLayer(); w; w = w->nextLayer())
+            if (w->visibleNow()) {
                 w->updateState();
 #ifdef CONFIG_TASKBAR
                 w->updateTaskBar();
 #endif
             }
 
-        for (w = topLayer(); w; w = w->nextLayer())
-            if (w->visibleNow()) {
+        for (w = bottomLayer(); w; w = w->prevLayer())
+            if (!w->visibleNow()) {
                 w->updateState();
 #ifdef CONFIG_TASKBAR
                 w->updateTaskBar();
@@ -2594,6 +2597,7 @@ void YWindowManager::saveArrange(YFrameWindow **w, int count) {
 }
 void YWindowManager::undoArrange() {
     if (fArrangeInfo) {
+        lockFocus();
         for (int i = 0; i < fArrangeCount; i++) {
             YFrameWindow *f = fArrangeInfo[i].frame;
             if (f) {
@@ -2606,6 +2610,7 @@ void YWindowManager::undoArrange() {
         }
         delete [] fArrangeInfo; fArrangeInfo = 0;
         fArrangeCount = 0;
+        unlockFocus();
         focusTopWindow();
     }
 }
