@@ -541,8 +541,8 @@ MenuFileMenu::MenuFileMenu(const char *name, YWindow *parent): ObjectMenu(parent
 }
 
 MenuFileMenu::~MenuFileMenu() {
-    delete fPath; fPath = 0;
-    delete fName; fName = 0;
+    delete[] fPath; fPath = 0;
+    delete[] fName; fName = 0;
 }
 
 void MenuFileMenu::updatePopup() {
@@ -674,7 +674,7 @@ void MenuProgMenu::updatePopup() {
     if (fModTime == 0)
         refresh();
     fModTime = time(NULL);
-#warning "figure out some way for this to work"
+/// TODO #warning "figure out some way for this to work"
 }
 
 void MenuProgMenu::refresh() {
@@ -737,7 +737,7 @@ void StartMenu::refresh() {
     }
 #endif
 
-#warning "make this into a menuprog (ala gnome.cc), and use mime"
+/// TODO #warning "make this into a menuprog (ala gnome.cc), and use mime"
     if (openCommand && openCommand[0]) {
         const char *path[2];
         YMenu *sub;
