@@ -96,7 +96,7 @@ MoveSizeStatus::~MoveSizeStatus() {
 
 const char* MoveSizeStatus::getStatus() {
     static char status[50];
-    sprintf(status, "%dx%d+%d+%d", fW, fH, fX, fY);
+    snprintf(status, 50, "%dx%d%+d%+d", fW, fH, fX, fY);
     return status;
 }
 
