@@ -52,9 +52,9 @@ YTimer *WorkspaceButton::fRaiseTimer(NULL);
 
 TaskBar *taskBar = 0;
 
-static YColor *taskBarBg = 0;
+YColor *taskBarBg = 0;
 
-static ref<YIconImage> icewmImage;
+static ref<YIconImage> startImage;
 static ref<YIconImage> windowsImage;
 static ref<YIconImage> showDesktopImage;
 static ref<YIconImage> collapseImage;
@@ -89,10 +89,7 @@ static void initPixmaps() {
     YResourcePaths themedirs(paths, base, true);
     YResourcePaths subdirs(paths, base);
 
-    if ((icewmImage = themedirs.loadImage(base, ICEWM_PIXMAP)) == null &&
-        (icewmImage = themedirs.loadImage(base, START_PIXMAP)) == null)
-        icewmImage = subdirs.loadImage(base, ICEWM_PIXMAP);
-
+    startImage = subdirs.loadImage(base, "start.xpm");
     windowsImage = subdirs.loadImage(base, "windows.xpm");
     showDesktopImage = subdirs.loadImage(base, "desktop.xpm");
     collapseImage = subdirs.loadImage(base, "collapse.xpm");
@@ -282,7 +279,7 @@ TaskBar::~TaskBar() {
     taskbuttonminimizedPixbuf = null;
     delete fGradient;
 #endif
-    icewmImage = null;
+    startImage = null;
     windowsImage = null;
     showDesktopImage = null;;
 #ifdef CONFIG_APPLET_MAILBOX
@@ -447,7 +444,7 @@ void TaskBar::initApplets() {
     if (taskBarShowStartMenu) {
         fApplications = new ObjectButton(this, rootMenu);
         fApplications->setActionListener(this);
-        fApplications->setImage(icewmImage);
+        fApplications->setImage(startImage);
         fApplications->setToolTip(_("Favorite applications"));
     } else
         fApplications = 0;
@@ -900,10 +897,19 @@ void TaskBar::handleClick(const XButtonEvent &up, int count) {
     }
 }
 
+void TaskBar::handleEndDrag(const XButtonEvent &/*down*/, const XButtonEvent &/*up*/) {
+    xapp->releaseEvents();
+}
 void TaskBar::handleDrag(const XButtonEvent &/*down*/, const XMotionEvent &motion) {
 #ifndef NO_CONFIGURE
     int newPosition = 0;
 
+    xapp->grabEvents(this, YXApplication::movePointer.handle(),
+                         ButtonPressMask |
+                         ButtonReleaseMask |
+                         PointerMotionMask);
+
+
     if (motion.y_root < int(desktop->height() / 2))
         newPosition = 1;
 
