@@ -111,6 +111,13 @@ int YWindow::fClickDrag = 0;
 unsigned int YWindow::fClickButton = 0;
 unsigned int YWindow::fClickButtonDown = 0;
 
+unsigned int ignore_enternotify_hack = 0; // credits to ahwm
+
+static void update_ignore_enternotify_hack(const XEvent &event) {
+    ignore_enternotify_hack = event.xany.serial;
+    XSync(xapp->display(), False);
+}
+
 /******************************************************************************/
 /******************************************************************************/
 
@@ -558,6 +565,7 @@ void YWindow::handleEvent(const XEvent &event) {
         break;
 
     case ConfigureNotify:
+        update_ignore_enternotify_hack(event);
 #if 1
          {
              XEvent new_event, old_event;
@@ -600,10 +608,12 @@ void YWindow::handleEvent(const XEvent &event) {
         handleGraphicsExpose(event.xgraphicsexpose); break;
 
     case MapNotify:
+        update_ignore_enternotify_hack(event);
         handleMapNotify(event.xmap);
         break;
 
     case UnmapNotify:
+        update_ignore_enternotify_hack(event);
         handleUnmapNotify(event.xunmap);
         break;
 
@@ -623,6 +633,14 @@ void YWindow::handleEvent(const XEvent &event) {
         handleSelection(event.xselection);
         break;
 
+    case GravityNotify:
+        update_ignore_enternotify_hack(event);
+        break;
+
+    case CirculateNotify:
+        update_ignore_enternotify_hack(event);
+        break;
+
     default:
 #ifdef CONFIG_SHAPE
         if (shapesSupported && event.type == (shapeEventBase + ShapeNotify))
@@ -1398,7 +1416,7 @@ void YWindow::handleXdnd(const XClientMessageEvent &message) {
             YWindow *win;
 
             if (XFindContext(xapp->display(), XdndDropTarget, windowContext,
-                             (XPointer *)&win) == 0)
+                             (XPointer *)(void *)&win) == 0)
                 win->handleDNDLeave();
             XdndDropTarget = None;
         }
@@ -1439,27 +1457,40 @@ void YWindow::handleXdnd(const XClientMessageEvent &message) {
 
         if (target != XdndDropTarget) {
             if (XdndDropTarget) {
-                YWindow *win;
+                union {
+                    YWindow *ptr;
+                    XPointer xptr;
+                } win;
 
                 if (XFindContext(xapp->display(), XdndDropTarget, windowContext,
-                                 (XPointer *)&win) == 0)
-                    win->handleDNDLeave();
+                                 &win.xptr) == 0)
+                    win.ptr->handleDNDLeave();
             }
             XdndDropTarget = target;
             if (XdndDropTarget) {
-                YWindow *win;
+                union {
+                    YWindow *ptr;
+                    XPointer xptr;
+                } win;
 
                 if (XFindContext(xapp->display(), XdndDropTarget, windowContext,
-                                 (XPointer *)&win) == 0)
+                                 &win.xptr) == 0)
                 {
-                    win->handleDNDEnter();
-                    pwin = win;
+                    win.ptr->handleDNDEnter();
+                    pwin = win.ptr;
                 }
             }
         }
         if (pwin == 0 && XdndDropTarget) { // !!! optimize this
+            union {
+                YWindow *ptr;
+                XPointer xptr;
+            } win;
             if (XFindContext(xapp->display(), XdndDropTarget, windowContext,
-                             (XPointer *)&pwin) != 0)
+                             &win.xptr) == 0)
+            {
+                pwin = win.ptr;
+            } else
                 pwin = 0;
         }
         if (pwin)
